@@ -4,10 +4,14 @@
 import os
 import re
 from contextlib import suppress
+from fnmatch import fnmatch
 from functools import lru_cache
 from hashlib import md5
+from typing import (
+    TYPE_CHECKING, Dict, Iterator, List, Optional, Sequence, Set, Tuple, Union
+)
+
 from kitty.guess_mime_type import guess_type
-from typing import TYPE_CHECKING, Dict, List, Set, Optional, Iterator, Tuple, Union
 
 if TYPE_CHECKING:
     from .highlight import DiffHighlight  # noqa
@@ -32,12 +36,13 @@ class Segment:
         self.end_code: Optional[str] = None
 
     def __repr__(self) -> str:
-        return 'Segment(start={!r}, start_code={!r}, end={!r}, end_code={!r})'.format(
-            self.start, self.start_code, self.end, self.end_code)
+        return f'Segment(start={self.start!r}, start_code={self.start_code!r}, end={self.end!r}, end_code={self.end_code!r})'
 
 
 class Collection:
 
+    ignore_names: Tuple[str, ...] = ()
+
     def __init__(self) -> None:
         self.changes: Dict[str, str] = {}
         self.renames: Dict[str, str] = {}
@@ -102,26 +107,38 @@ def remote_hostname(path: str) -> Tuple[Optional[str], Optional[str]]:
 def resolve_remote_name(path: str, default: str) -> str:
     remote_dir, rh = remote_hostname(path)
     if remote_dir and rh:
-        return rh + ':' + os.path.relpath(path, remote_dir)
+        return f'{rh}:{os.path.relpath(path, remote_dir)}'
     return default
 
 
+def allowed_items(items: Sequence[str], ignore_patterns: Sequence[str]) -> Iterator[str]:
+    for name in items:
+        for pat in ignore_patterns:
+            if fnmatch(name, pat):
+                break
+        else:
+            yield name
+
+
+def walk(base: str, names: Set[str], pmap: Dict[str, str], ignore_names: Tuple[str, ...]) -> None:
+    for dirpath, dirnames, filenames in os.walk(base):
+        dirnames[:] = allowed_items(dirnames, ignore_names)
+        for filename in allowed_items(filenames, ignore_names):
+            path = os.path.abspath(os.path.join(dirpath, filename))
+            path_name_map[path] = name = os.path.relpath(path, base)
+            names.add(name)
+            pmap[name] = path
+
+
 def collect_files(collection: Collection, left: str, right: str) -> None:
     left_names: Set[str] = set()
     right_names: Set[str] = set()
     left_path_map: Dict[str, str] = {}
     right_path_map: Dict[str, str] = {}
 
-    def walk(base: str, names: Set[str], pmap: Dict[str, str]) -> None:
-        for dirpath, dirnames, filenames in os.walk(base):
-            for filename in filenames:
-                path = os.path.abspath(os.path.join(dirpath, filename))
-                path_name_map[path] = name = os.path.relpath(path, base)
-                names.add(name)
-                pmap[name] = path
+    walk(left, left_names, left_path_map, collection.ignore_names)
+    walk(right, right_names, right_path_map, collection.ignore_names)
 
-    walk(left, left_names, left_path_map)
-    walk(right, right_names, right_path_map)
     common_names = left_names & right_names
     changed_names = {n for n in common_names if data_for_path(left_path_map[n]) != data_for_path(right_path_map[n])}
     for n in changed_names:
