@@ -12,8 +12,8 @@ from .borders import Border, BorderColor
 from .config import build_ansi_color_table
 from .constants import config_dir
 from .fast_data_types import (
-    DECAWM, Region, Screen, cell_size_for_window, get_options, pt_to_px,
-    set_tab_bar_render_data, viewport_for_window, Color
+    DECAWM, Color, Region, Screen, cell_size_for_window, get_boss, get_options,
+    pt_to_px, set_tab_bar_render_data, viewport_for_window
 )
 from .rgb import alpha_blend, color_as_sgr, color_from_int, to_color
 from .types import WindowGeometry, run_once
@@ -25,6 +25,7 @@ class TabBarData(NamedTuple):
     title: str
     is_active: bool
     needs_attention: bool
+    tab_id: int
     num_windows: int
     num_window_groups: int
     layout_name: str
@@ -172,13 +173,31 @@ def template_has_field(template: str, field: str) -> bool:
     return False
 
 
-def draw_title(draw_data: DrawData, screen: Screen, tab: TabBarData, index: int) -> None:
+class TabAccessor:
+
+    def __init__(self, tab_id: int):
+        self.tab_id = tab_id
+
+    @property
+    def active_wd(self) -> str:
+        tab = get_boss().tab_for_id(self.tab_id)
+        return (tab.get_cwd_of_active_window() if tab else '') or ''
+
+
+safe_builtins = {
+    'max': max, 'min': min, 'str': str, 'repr': repr, 'abs': abs, 'len': len,
+}
+
+
+def draw_title(draw_data: DrawData, screen: Screen, tab: TabBarData, index: int, max_title_length: int = 0) -> None:
+    ta = TabAccessor(tab.tab_id)
     data = {
         'index': index,
         'layout_name': tab.layout_name,
         'num_windows': tab.num_windows,
         'num_window_groups': tab.num_window_groups,
         'title': tab.title,
+        'tab': ta,
     }
     ColorFormatter.draw_data = draw_data
     ColorFormatter.tab_data = tab
@@ -188,11 +207,13 @@ def draw_title(draw_data: DrawData, screen: Screen, tab: TabBarData, index: int)
         'num_windows': tab.num_windows,
         'num_window_groups': tab.num_window_groups,
         'title': tab.title,
+        'tab': ta,
         'fmt': Formatter,
         'sup': SupSub(data),
         'sub': SupSub(data, True),
         'bell_symbol': draw_data.bell_on_tab if tab.needs_attention else '',
         'activity_symbol': draw_data.tab_activity_symbol if tab.has_activity_since_last_focus else '',
+        'max_title_length': max_title_length,
     }
     template = draw_data.title_template
     if tab.is_active and draw_data.active_title_template is not None:
@@ -203,9 +224,9 @@ def draw_title(draw_data: DrawData, screen: Screen, tab: TabBarData, index: int)
     if eval_locals['activity_symbol'] and not template_has_field(template, 'activity_symbol'):
         prefix += '{activity_symbol}'
     if prefix:
-        template = '{fmt.fg.red}' + prefix + '{fmt.fg.default}' + template
+        template = '{fmt.fg.red}' + prefix + '{fmt.fg.tab}' + template
     try:
-        title = eval(compile_template(template), {'__builtins__': {}}, eval_locals)
+        title = eval(compile_template(template), {'__builtins__': safe_builtins}, eval_locals)
     except Exception as e:
         report_template_failure(template, str(e))
         title = tab.title
@@ -244,7 +265,7 @@ def draw_tab_with_slant(
     else:
         draw_sep(left_sep)
         screen.draw(' ')
-        draw_title(draw_data, screen, tab, index)
+        draw_title(draw_data, screen, tab, index, max_title_length)
         extra = screen.cursor.x - before - max_title_length
         if extra >= 0:
             screen.cursor.x -= extra + 3
@@ -265,7 +286,7 @@ def draw_tab_with_separator(
 ) -> int:
     if draw_data.leading_spaces:
         screen.draw(' ' * draw_data.leading_spaces)
-    draw_title(draw_data, screen, tab, index)
+    draw_title(draw_data, screen, tab, index, max_title_length)
     trailing_spaces = min(max_title_length - 1, draw_data.trailing_spaces)
     max_title_length -= trailing_spaces
     extra = screen.cursor.x - before - max_title_length
@@ -296,11 +317,11 @@ def draw_tab_with_fade(
         screen.cursor.bg = bg
         screen.draw(' ')
     screen.cursor.bg = orig_bg
-    draw_title(draw_data, screen, tab, index)
+    draw_title(draw_data, screen, tab, index, max(0, max_title_length - 8))
     extra = screen.cursor.x - before - max_title_length
     if extra > 0:
         screen.cursor.x = before
-        draw_title(draw_data, screen, tab, index)
+        draw_title(draw_data, screen, tab, index, max(0, max_title_length - 4))
         extra = screen.cursor.x - before - max_title_length
         if extra > 0:
             screen.cursor.x -= extra + 1
@@ -351,7 +372,7 @@ def draw_tab_with_powerline(
     if min_title_length >= max_title_length:
         screen.draw('…')
     else:
-        draw_title(draw_data, screen, tab, index)
+        draw_title(draw_data, screen, tab, index, max_title_length)
         extra = screen.cursor.x + start_draw - before - max_title_length
         if extra > 0 and extra + 1 < screen.cursor.x:
             screen.cursor.x -= extra + 1
@@ -501,6 +522,10 @@ class TabBar:
         fg = spec.get('inactive_tab_foreground')
         if fg is None:
             fg = color_as_int(opts.inactive_tab_foreground)
+        else:
+            ifg = color_from_int(fg)
+            if ifg is not None:
+                self.draw_data = self.draw_data._replace(inactive_fg=ifg)
         self.screen.color_profile.set_configured_colors(fg, bg)
 
     def update_blank_rects(self, central: Region, tab_bar: Region, vw: int, vh: int) -> None:
